plot method for bayesTestResults object

plot method for powerTestResults object

# S3 method for bayesTestResults
plot(x, xAxis, yAxis, fill, ...)

# S3 method for powerTestResults
plot(x, xAxis, yAxis, fill, ...)

Arguments

x

object to plot

xAxis

unquoted column name containing the data to plot on the x axis of the tile plot

yAxis

unquoted column name containing the data to plot on the y axis of the tile plot

fill

unquoted column name containing the data to file the tile plot

...

S3 method compatibility