Runs Frequentist power analysis for 2 proportions on multiple sample sizes

runFrequentistPower(
  topScorerHitRate,
  topScorerSampleSize,
  lowScorerhitRate,
  lowScorerSampleSize,
  sig.level = 0.05,
  power = NULL,
  alternative = c("two.sided", "less", "greater")
)

Arguments

topScorerHitRate

Numeric, hit rate for the top scorer

topScorerSampleSize

Named numeric vector, group size for the top scorer

lowScorerhitRate

Numeric, hit rate for the low scorer

lowScorerSampleSize

Named numeric vector, group size for the low scorer

sig.level

Significance level (Type I error probability)

power

Power of test (1 minus Type II error probability)

alternative

a character string specifying the alternative hypothesis, must be one of "two.sided" (default), "greater" or "less"

Value

effectSize

numeric - Cohen's index Effect size ES.h

topScorerSampleSize

numeric - top-scorer sample size

lowScorerSampleSize

numeric - low-scorer sample size

pvalue

numeric - Significance level (Type I error probability)

power

numeric - Power of test (1 minus Type II error probability)

alternative

character - alternative hypothesis

note

character - Notes

alternative

character - Method used to run the power analysis

See also