plot.Rdplot method for bayesTestResults object
plot method for powerTestResults object
object to plot
unquoted column name containing the data to plot on the x axis of the tile plot
unquoted column name containing the data to plot on the y axis of the tile plot
unquoted column name containing the data to file the tile plot
S3 method compatibility