runFrequentistPower.RdRuns Frequentist power analysis for 2 proportions on multiple sample sizes
runFrequentistPower(
topScorerHitRate,
topScorerSampleSize,
lowScorerhitRate,
lowScorerSampleSize,
sig.level = 0.05,
power = NULL,
alternative = c("two.sided", "less", "greater")
)Numeric, hit rate for the top scorer
Named numeric vector, group size for the top scorer
Numeric, hit rate for the low scorer
Named numeric vector, group size for the low scorer
Significance level (Type I error probability)
Power of test (1 minus Type II error probability)
a character string specifying the alternative hypothesis, must be one of "two.sided" (default), "greater" or "less"
numeric - Cohen's index Effect size ES.h
numeric - top-scorer sample size
numeric - low-scorer sample size
numeric - Significance level (Type I error probability)
numeric - Power of test (1 minus Type II error probability)
character - alternative hypothesis
character - Notes
character - Method used to run the power analysis